==> sitemodels-0.3.25.tgz: package/gulpfile.js <==
var gulp = require('gulp'),
    sass = require('gulp-sass'),
    sync = require('browser-sync').create(),
    sm = require('./index.js');



function syncSite() {
  sync.init({ 
    server: 'tests/output',
    notify: false 
  });
}

function sassBuild() {
  gulp.src('assets/scss/*.scss')
    .pipe(sass({
      outputStyle: 'nested'
    }))
    .pipe(gulp.dest('assets/css'))
    .pipe(gulp.dest('tests/output/css'));
}

function smBuild() {
  sm({
    name: 'Testing',
    root: 'tests', // From execution point
    sass: 'tests/sass', // From execution point
    js: 'tests/js', // From execution point
    output: 'tests/output', // From execution point
    structure: ['Elements', 'Components', 'Sections', 'States'],
    js_dependencies: ['jquery-3.1.1.min.js'],
    css_output_style: 'nested'
  })
}



gulp.task('syncStart', syncSite);

gulp.task('sass', sassBuild);

gulp.task('sm', smBuild);

gulp.task('sm-dev', ['syncStart', 'sass', 'sm'], function() {
  gulp.watch([
    'assets/scss/**/*',
    'assets/js/**/*',
    'templates/**/*',
    'tests/testSass/**/*',
    'tests/sass/**/*',
    'tests/docs/**/*',
    'README.md'
  ],
  ['sass', 'sm', 'syncReload']);
})

gulp.task('syncReload', function() {
  sync.reload();
});



gulp.task('default', ['syncStart'], function() {
  gulp.watch('assets/scss/**/*.scss', ['sass', 'syncReload']);
  gulp.watch([
    'index.js',
    'lib/*.js',
    'assets/js/**/*.js',
    'templates/*.html',
    'tests/testSass/**/*.scss',
    'tests/js/**/*.js'
    ], 
    ['sm', 'syncReload']);
})

==> sitemodels-0.3.31.tgz: package/gulpfile.js <==
var gulp = require('gulp'),
    sass = require('gulp-sass'),
    sync = require('browser-sync').create(),
    sassdoc = require('sassdoc'),
    sm = require('./index.js');



function syncSite() {
  sync.init({ 
    server: 'tests/output',
    notify: false 
  });
}

function sassDocumentation() {
  gulp.src('tests/sass/**/*.scss')
    .pipe(sassdoc({
      dest: 'tests/sassdoc'
    }));
}

function sassBuild() {
  gulp.src('assets/scss/*.scss')
    .pipe(sass({
      outputStyle: 'nested'
    }))
    .pipe(gulp.dest('assets/css'))
    .pipe(gulp.dest('tests/output/css'));
}

function smBuild() {
  sm({
    name: 'Testing',
    root: 'tests', // From execution point
    sass: 'tests/sass', // From execution point
    js: 'tests/js', // From execution point
    output: 'tests/output', // From execution point
    structure: ['Elements', 'Components', 'Sections', 'States'],
    js_dependencies: ['jquery-3.1.1.min.js'],
    css_output_style: 'nested',
    sassdoc: 'tests/sassdoc'
  })
}



gulp.task('syncStart', syncSite);

gulp.task('docs', sassDocumentation);

gulp.task('sass', sassBuild);

gulp.task('sm', smBuild);

gulp.task('sm-dev', ['syncStart', 'docs', 'sass', 'sm'], function() {
  gulp.watch([
    'assets/scss/**/*',
    'assets/js/**/*',
    'templates/**/*',
    'tests/testSass/**/*',
    'tests/sass/**/*',
    'tests/docs/**/*',
    'README.md'
  ],
  ['docs', 'sass', 'sm', 'syncReload']);
})

gulp.task('syncReload', function() {
  sync.reload();
});



gulp.task('default', ['syncStart'], function() {
  gulp.watch('assets/scss/**/*.scss', ['sass', 'syncReload']);
  gulp.watch([
    'index.js',
    'lib/*.js',
    'assets/js/**/*.js',
    'templates/*.html',
    'tests/testSass/**/*.scss',
    'tests/js/**/*.js'
    ], 
    ['sm', 'syncReload']);
})
